@@ -1,25 +1,31 @@
 import operator
 # attributes for PIV variables
+
+v_x = "v_x"
+v_y = "v_y"
+s2n = "s2n"
+corr = "corr"
+
 PIV_ATTRS = {
-    "v_x": {
+    v_x: {
         "standard_name": "sea_water_x_velocity",
         "long_name": "Flow element center velocity vector, x-component",
         "units": "m s-1",
         "coordinates": "lon lat",
     },
-    "v_y": {
+    v_y: {
         "standard_name": "sea_water_x_velocity",
         "long_name": "Flow element center velocity vector, x-component",
         "units": "m s-1",
         "coordinates": "lon lat"
     },
-    "s2n": {
+    s2n: {
         "standard_name": "ratio",
         "long_name": "signal to noise ratio",
         "units": "",
         "coordinates": "lon lat",
     },
-    "corr": {
+    corr: {
         "standard_name": "correlation_coefficient",
         "long_name": "correlation coefficient between frames",
         "units": "",
@@ -82,7 +88,7 @@ ENCODING_PARAMS = {
     "_FillValue": -9999
 }
 
-ENCODE_VARS = ["v_x", "v_y", "corr", "s2n"]
+ENCODE_VARS = [v_x, v_y, corr, s2n]
 ENCODING = {k: ENCODING_PARAMS for k in ENCODE_VARS}
 
 FIGURE_ARGS = {
